@@ -21,7 +21,6 @@
 #include <kabc/stdaddressbook.h>
 #include <KStandardDirs>
 #include <KApplication>
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KLocale>
 
@@ -63,11 +62,14 @@ KeyListViewItem::KeyListViewItem(K3ListView *parent, const KgpgKey &key, const b
 	groupId = NULL;
 	if (key.secret())
 		m_type |= Secret;
-	setText(0, key.name());
+	if (key.comment().isEmpty())
+		setText(0, key.name());
+	else
+		setText(0, i18nc("Name (Comment)", "%1 (%2)", key.name(), key.comment()));
 	setText(1, key.email());
 	setText(2, QString());
 	setText(3, key.expiration());
-	setText(4, key.size());
+	setText(4, QString::number(key.size()));
 	setText(5, key.creation());
 	setText(6, key.id());
 }
@@ -195,25 +197,9 @@ int KeyListViewItem::compare(Q3ListViewItem *itemx, int c, bool ascending) const
 
 		return 0;
 	}
-	case 2: {	// pixmap
-		const QPixmap* pix = pixmap(c);
-		const QPixmap* itemPix = item->pixmap(c);
-
-		int serial;
-		int itemSerial;
-
-		if (!pix)
-			serial = 0;
-		else
-			serial = pix->serialNumber();
-
-		if (!itemPix)
-			itemSerial = 0;
-		else
-			itemSerial = itemPix->serialNumber();
-
-		if (serial < itemSerial) return -1;
-		if (serial > itemSerial) return  1;
+	case 2: {       // trust
+		if (trust() < item->trust()) return -1;
+		if (trust() > item->trust()) return 1;
 		return 0;
 	}
 	case 0: {
@@ -383,7 +369,7 @@ void KeyListView::slotReloadKeys(const QStringList &keyids)
     refreshKeys(keyids);
 
     ensureItemVisible(this->findItemByKeyId(keyids.last()));
-    emit statusMessage(i18n("%1 Keys, %2 Groups", childCount() - groupNb, groupNb), 1);
+    emit statusMessage(statusCountMessage(), 1);
     emit statusMessage(i18n("Ready"), 0);
 }
 
@@ -439,7 +425,7 @@ void KeyListView::refreshAll()
         setSelected(firstChild(), true);
     }
 
-    emit statusMessage(i18n("%1 Keys, %2 Groups", childCount() - groupNb, groupNb), 1);
+    emit statusMessage(statusCountMessage(), 1);
     emit statusMessage(i18n("Ready"),0);
     kDebug(2100) << "Refresh Finished" ;
 }
@@ -449,9 +435,7 @@ bool KeyListView::refreshKeys(const QStringList &ids)
     KgpgInterface *interface = new KgpgInterface();
     KgpgKeyList secretlist = interface->readSecretKeys(ids);
 
-    QStringList issec;
-    for (int i = 0; i < secretlist.size(); ++i)
-        issec << secretlist.at(i).fullId();
+    QStringList issec = secretlist;
 
     KgpgKeyList publiclist = interface->readPublicKeys(true, ids);
     delete interface;
@@ -472,6 +456,7 @@ bool KeyListView::refreshKeys(const QStringList &ids)
         {
             key.setSecret(true);
             issec.removeAt(index);
+            secretlist.removeAt(index);
         }
 
         item = new KeyListViewItem(this, key, isbold);
@@ -486,12 +471,13 @@ bool KeyListView::refreshKeys(const QStringList &ids)
     }
 
     if (!issec.isEmpty())
-        insertOrphans(issec);
+        insertOrphans(secretlist);
 
     if (publiclist.size() == 0)
         return 1;
     else
     {
+        sort();
         if (publiclist.size() == 1)
         {
             clearSelection();
@@ -501,6 +487,11 @@ bool KeyListView::refreshKeys(const QStringList &ids)
     }
 }
 
+void KeyListView::refreshcurrentkey(const QString &id)
+{
+	refreshcurrentkey(findItemByKeyId(id));
+}
+
 void KeyListView::refreshcurrentkey(KeyListViewItem *current)
 {
     if (!current)
@@ -533,14 +524,13 @@ void KeyListView::slotReloadOrphaned()
     QStringList issec;
 
     KgpgInterface *interface = new KgpgInterface();
-    KgpgKeyList listkeys;
+    KgpgKeyList listkeys, seckeys;
 
-    listkeys = interface->readSecretKeys();
+    seckeys = interface->readSecretKeys();
+    issec = seckeys;
+    listkeys = interface->readPublicKeys(true, issec);
     for (int i = 0; i < listkeys.size(); ++i)
-        issec << listkeys.at(i).id();
-    listkeys = interface->readPublicKeys(true);
-    for (int i = 0; i < listkeys.size(); ++i)
-        issec.removeAll(listkeys.at(i).id());
+        issec.removeAll(listkeys.at(i).fullId());
 
     delete interface;
 
@@ -551,18 +541,15 @@ void KeyListView::slotReloadOrphaned()
             list += *it;
 
     if (list.size() != 0)
-        insertOrphans(list);
+        insertOrphans(seckeys);
 
     setSelected(findItemByKeyId(*it), true);
-    emit statusMessage(i18n("%1 Keys, %2 Groups", childCount() - groupNb, groupNb), 1);
+    emit statusMessage(statusCountMessage(), 1);
     emit statusMessage(i18n("Ready"), 0);
 }
 
-void KeyListView::insertOrphans(const QStringList &ids)
+void KeyListView::insertOrphans(const KgpgKeyList &keys)
 {
-    KgpgInterface *interface = new KgpgInterface();
-    KgpgKeyList keys = interface->readSecretKeys(ids);
-    delete interface;
     QStringList orphanList;
 
     KeyListViewItem *item = 0;
@@ -577,19 +564,11 @@ void KeyListView::insertOrphans(const QStringList &ids)
         item->setPixmap(0, Images::orphan());
     }
 
-    if (ids.size() == 1)
+    if (keys.size() == 1)
     {
-        if (keys.isEmpty())
-        {
-            orphanList.removeAll(ids.at(0));
-            setSelected(currentItem(), true);
-        }
-        else
-        {
-            clearSelection();
-            setCurrentItem(item);
-            setSelected(item, true);
-        }
+        clearSelection();
+        setCurrentItem(item);
+        setSelected(item, true);
     }
 }
 
@@ -621,7 +600,7 @@ void KeyListView::refreshGroups()
             item->setExpandable(true);
         }
 
-    emit statusMessage(i18n("%1 Keys, %2 Groups", childCount() - groupNb, groupNb), 1);
+    emit statusMessage(statusCountMessage(), 1);
     emit statusMessage(i18n("Ready"), 0);
 }
 
@@ -827,8 +806,12 @@ QList<KeyListViewItem *> KeyListView::selectedItems(void)
 
 	Q3ListViewItemIterator it(this, Q3ListViewItemIterator::Selected);
 
-	for(; it.current(); ++it)
-		list.append(static_cast<KeyListViewItem*>(it.current()));
+	for(; it.current(); ++it) {
+		Q3ListViewItem *q = Q3ListViewItem(*it).parent();
+		if ((q->depth() > 0) && !q->parent()->isOpen())
+			continue;
+		list.append(static_cast<KeyListViewItem*>(q));
+	}
 
 	return list;
 }
@@ -865,6 +848,19 @@ KeyListViewItem *KeyListView::findItemByKeyId(const QString &id)
 	return NULL;
 }
 
+QString KeyListView::statusCountMessage(void)
+{
+	QString kmsg = i18np("1 Key", "%1 Keys", childCount() - groupNb);
+
+	if (groupNb == 0) {
+		return kmsg;
+	} else {
+		QString gmsg = i18np("1 Group", "%1 Groups", groupNb);
+
+		return kmsg + ", " + gmsg;
+	}
+}
+
 KeyListViewSearchLine::KeyListViewSearchLine(QWidget *parent, KeyListView *listView)
                      : K3ListViewSearchLine(parent, listView)
 {
