@@ -65,7 +65,6 @@
 #include <KDesktopFile>
 #include <KInputDialog>
 #include <KFileDialog>
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KFindDialog>
 #include <KStatusBar>
@@ -93,6 +92,7 @@
 #include <KVBox>
 #include <KToggleAction>
 
+#include "kgpgkey.h"
 #include "selectsecretkey.h"
 #include "newkey.h"
 #include "kgpg.h"
@@ -112,8 +112,6 @@
 #include "images.h"
 #include "sourceselect.h"
 
-
-
 using namespace KgpgCore;
 
 KeysManager::KeysManager(QWidget *parent)
@@ -187,7 +185,7 @@ KeysManager::KeysManager(QWidget *parent)
     QAction *infoKey = actionCollection()->addAction("key_info");
     infoKey->setIcon(KIcon("kgpg-info-kgpg"));
     infoKey->setText(i18n("K&ey properties"));
-    connect(infoKey, SIGNAL(triggered(bool)), SLOT(listsigns()));
+    connect(infoKey, SIGNAL(triggered(bool)), SLOT(keyproperties()));
     infoKey->setShortcut(QKeySequence(Qt::Key_Return));
 
     QAction *editKey = actionCollection()->addAction("key_edit");
@@ -223,15 +221,15 @@ KeysManager::KeysManager(QWidget *parent)
     createGroup->setText(i18n("&Create Group with Selected Keys..."));
     connect(createGroup, SIGNAL(triggered(bool)), SLOT(createNewGroup()));
 
-    QAction *editCurrentGroup = actionCollection()->addAction("edit_group");
+    editCurrentGroup = actionCollection()->addAction("edit_group");
     editCurrentGroup->setText(i18n("&Edit Group"));
     connect(editCurrentGroup, SIGNAL(triggered(bool)), SLOT(editGroup()));
 
-    QAction *delGroup = actionCollection()->addAction("delete_group");
+    delGroup = actionCollection()->addAction("delete_group");
     delGroup->setText(i18n("&Delete Group"));
     connect(delGroup, SIGNAL(triggered(bool)), SLOT(deleteGroup()));
 
-    QAction *deleteKey = actionCollection()->addAction("key_delete");
+    deleteKey = actionCollection()->addAction("key_delete");
     deleteKey->setIcon(KIcon("edit-delete"));
     deleteKey->setText(i18n("&Delete Keys"));
     connect(deleteKey, SIGNAL(triggered(bool)), SLOT(confirmdeletekey()));
@@ -388,8 +386,8 @@ KeysManager::KeysManager(QWidget *parent)
     setCentralWidget(keysList2);
     keysList2->restoreLayout(KGlobal::config().data(), "KeyView");
 
-    connect(keysList2, SIGNAL(returnPressed(Q3ListViewItem *)), this, SLOT(listsigns()));
-    connect(keysList2, SIGNAL(doubleClicked(Q3ListViewItem *, const QPoint &, int)), this, SLOT(listsigns()));
+    connect(keysList2, SIGNAL(returnPressed(Q3ListViewItem *)), this, SLOT(defaultAction()));
+    connect(keysList2, SIGNAL(doubleClicked(Q3ListViewItem *, const QPoint &, int)), this, SLOT(defaultAction()));
     connect(keysList2, SIGNAL(selectionChanged ()), this, SLOT(checkList()));
     connect(keysList2, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)), this, SLOT(slotMenu(Q3ListViewItem *, const QPoint &, int)));
     connect(keysList2, SIGNAL(destroyed()), this, SLOT(annule()));
@@ -510,7 +508,7 @@ void KeysManager::slotGenerateKeyProcess(KgpgInterface *)
     pop = new KPassivePopup(this);
     pop->setTimeout(0);
 
-    KVBox *passiveBox = pop->standardView(i18n("Generating new key pair."), QString(), KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop), 0);
+    KVBox *passiveBox = pop->standardView(i18n("Generating new key pair."), QString(), Images::kgpg(), 0);
 
     QMovie anim(KStandardDirs::locate("appdata", "pics/kgpg_anim.gif"));
     QLabel *text1 = new QLabel(passiveBox);
@@ -573,7 +571,7 @@ void KeysManager::slotGenerateKeyDone(int res, KgpgInterface *interface, const Q
     }
     else
     {
-        changeMessage(i18n("%1 Keys, %2 Groups", keysList2->childCount() - keysList2->groupNb, keysList2->groupNb), 1);
+        changeMessage(keysList2->statusCountMessage(), 1);
 
         KDialog *keyCreated = new KDialog(this);
         keyCreated->setCaption(i18n("New Key Pair Created"));
@@ -715,44 +713,46 @@ void KeysManager::refreshKeyFromServer()
     if (keysList2->currentItem() == NULL)
         return;
 
-    QStringList *keyIDS = new QStringList();
+    QStringList keyIDS;
     keysList = keysList2->selectedItems();
 
-    for (int i = 0; i < keysList.count(); ++i) {
-	KeyListViewItem *item = keysList.at(i);
+    for (int i = 0; i < keysList.count(); ++i)
+    {
+        KeyListViewItem *item = keysList.at(i);
 
         if (item)
         {
-		if (item->itemType() == KeyListViewItem::Group) {
-			KeyListViewItem *cur = item->firstChild();
+            if (item->itemType() == KeyListViewItem::Group)
+            {
+                KeyListViewItem *cur = item->firstChild();
 
-			if (!cur) {
-				item->setOpen(true);
-				item->setOpen(false);
-				cur = item->firstChild();
-			}
-			while (cur) {
-				*keyIDS << cur->keyId();
-				cur = cur->nextSibling();
-			}
-			continue;
-		}
-		if (item->itemType() & KeyListViewItem::Group)
-			continue;
+                if (!cur)
+                {
+                    item->setOpen(true);
+                    item->setOpen(false);
+                    cur = item->firstChild();
+                }
 
-		KgpgKey *key = item->getKey();
+                while (cur)
+                {
+                    keyIDS << cur->keyId();
+                    cur = cur->nextSibling();
+                }
 
-		if ((item->depth() != 0) || !key) {
-			KMessageBox::sorry(this, i18n("You can only refresh primary keys. Please check your selection."));
-                        delete keyIDS;
-			return;
-		} else {
-			*keyIDS << key->fullId();
-		}
+                continue;
+            }
+
+            if (item->itemType() & KeyListViewItem::Pair)
+                keyIDS << item->keyId();
+            else
+            {
+                KMessageBox::sorry(this, i18n("You can only refresh primary keys. Please check your selection."));
+                return;
+            }
         }
     }
 
-    kServer = new KeyServer(0, false);
+    kServer = new KeyServer(this, false);
     connect(kServer, SIGNAL(importFinished(QStringList)), this, SLOT(refreshFinished(QStringList)));
     kServer->refreshKeys(keyIDS);
 }
@@ -763,8 +763,7 @@ void KeysManager::refreshFinished(const QStringList &ids)
         kServer = 0L;
 
     for (int i = 0; i < ids.count(); ++i)
-        if (keysList.at(i))
-            keysList2->refreshcurrentkey(keysList.at(i));
+        keysList2->refreshcurrentkey(ids.at(i));
 }
 
 void KeysManager::slotDelUid()
@@ -782,7 +781,7 @@ void KeysManager::slotDelUid()
     args << "--edit-key" << item->keyId() << "uid" << uitem->text(6) << "deluid";
     process->start(terminalApp, args);
     process->waitForFinished();
-    keysList2->refreshselfkey();
+    keysList2->refreshcurrentkey(item);
 }
 
 void KeysManager::slotPrimUid()
@@ -800,26 +799,42 @@ void KeysManager::slotPrimUid()
     args << "--edit-key" << item->keyId() << "uid" << uitem->text(6) << "primary" << "save";
     process->start(terminalApp, args);
     process->waitForFinished();
-    keysList2->refreshselfkey();
+    keysList2->refreshcurrentkey(item);
 }
 
 void KeysManager::slotregenerate()
 {
-    FILE *fp;
-    QString tst;
-    char line[300];
-    QString regID = keysList2->currentItem()->keyId();
+	QString regID = keysList2->currentItem()->keyId();
+	KProcess *p1, *p2, *p3;
 
-    QString cmd = "gpg --no-secmem-warning --export-secret-key " + regID + " | gpgsplit --no-split --secret-to-public | gpg --import";
+	p1 = new KProcess(this);
+	*p1 << KGpgSettings::gpgBinaryPath() << "--no-secmem-warning" << "--export-secret-key" << regID;
+	p1->setOutputChannelMode(KProcess::OnlyStdoutChannel);
 
-    fp = popen(cmd.toAscii(), "r");
-    while (fgets(line, sizeof(line), fp))
-    {
-        tst += line;
-    }
-    pclose(fp);
-    keysList2->takeItem(keysList2->currentItem());
-    keysList2->refreshKeys(QStringList(regID));
+	p2 = new KProcess(this);
+	*p2 << "gpgsplit" << "--no-split" << "--secret-to-public";
+	p2->setOutputChannelMode(KProcess::OnlyStdoutChannel);
+
+	p3 = new KProcess(this);
+	*p3 << KGpgSettings::gpgBinaryPath() << "--import";
+
+	p1->setStandardOutputProcess(p2);
+	p2->setStandardOutputProcess(p3);
+
+	p1->start();
+	p2->start();
+	p3->start();
+
+	p1->waitForFinished();
+	p2->waitForFinished();
+	p3->waitForFinished();
+
+	delete p1;
+	delete p2;
+	delete p3;
+
+	keysList2->takeItem(keysList2->currentItem());
+	keysList2->refreshKeys(QStringList(regID));
 }
 
 void KeysManager::slotAddUid()
@@ -874,7 +889,7 @@ void KeysManager::slotDeletePhoto()
                         item->text(6), parent->text(0), parent->text(1));
 
     /*
-    if (KMessageBox::warningContinueCancel(this, mess, i18n("Warning"), KGuiItem(i18n("Delete"), "edit-delete")) != KMessageBox::Continue)
+    if (KMessageBox::warningContinueCancel(this, mess, QString(), KGuiItem(i18n("Delete"), "edit-delete")) != KMessageBox::Continue)
         return;
     */
 
@@ -1139,7 +1154,7 @@ void KeysManager::closeEvent (QCloseEvent *e)
 void KeysManager::showKeyServer()
 {
     KeyServer *ks = new KeyServer(this);
-    connect(ks, SIGNAL(importFinished(QStringList)), keysList2, SLOT(refreshKeys(QStringList())));
+    connect(ks, SIGNAL(importFinished(QStringList)), keysList2, SLOT(refreshKeys(QStringList)));
     ks->exec();
     delete ks;
     refreshkey();
@@ -1228,7 +1243,7 @@ void KeysManager::readOptions()
     QStringList groups = KgpgInterface::getGpgGroupNames(KGpgSettings::gpgConfigPath());
     KGpgSettings::setGroups(groups.join(","));
     keysList2->groupNb = groups.count();
-    changeMessage(i18n("%1 Keys, %2 Groups", keysList2->childCount() - keysList2->groupNb, keysList2->groupNb), 1);
+    changeMessage(keysList2->statusCountMessage(), 1);
 
     showTipOfDay = KGpgSettings::showTipOfDay();
 }
@@ -1275,10 +1290,8 @@ void KeysManager::slotSetDefaultKey(const QString &newID)
 
 void KeysManager::slotSetDefaultKey(KeyListViewItem *newdef)
 {
-    Q_ASSERT(newdef->pixmap(2) != NULL);
-
-    if ((newdef->pixmap(2)->serialNumber()!=keysList2->trustgood.serialNumber()) &&
-        (newdef->pixmap(2)->serialNumber()!=keysList2->trustultimate.serialNumber()))
+    if ((newdef->trust() != TRUST_FULL) &&
+        (newdef->trust() != TRUST_ULTIMATE))
     {
         KMessageBox::sorry(this, i18n("<qt>Sorry, the key <b>%1</b> is not valid for encryption or not trusted.</qt>", newdef->keyId()));
         return;
@@ -1309,114 +1322,73 @@ bool KeysManager::isSignatureUnknown(KeyListViewItem *item)
 
 void KeysManager::slotMenu(Q3ListViewItem *sel2, const QPoint &pos, int)
 {
-    KeyListViewItem *sel = static_cast<KeyListViewItem *>(sel2);
+	KeyListViewItem *sel = static_cast<KeyListViewItem *>(sel2);
 
-    // popup a different menu depending on which key is selected
-    if (sel != 0)
-    {
-        if (keysList2->selectedItems().count() > 1)
-        {
-            QList<KeyListViewItem*> exportList = keysList2->selectedItems();
-            bool keyDepth = true;
-            bool allunksig = true;
-            bool allsig = true;
+	if (sel == NULL) {
+		m_popupout->exec(pos);
+		return;
+	}
 
-            for (int i = 0; i < exportList.count(); ++i) {
-                KeyListViewItem *cur = exportList.at(i);
-                if (cur)
-                    if (cur->depth() != 0) {
-                        if (!(cur->itemType() & KeyListViewItem::Group))
-                            keyDepth = false;
-                        allsig &= isSignature(exportList.at(i));
-                        allunksig &= isSignatureUnknown(exportList.at(i));
-                    } else {
-                      allunksig = false;
-                      allsig = false;
-                    }
-            }
+	KeyListViewItem::ItemType t = 0;
+	QList<KeyListViewItem*> exportList = keysList2->selectedItems();
+	int i;
+	bool allunksig = true;
+	int cnt = exportList.count();
+	bool unksig = false;
 
-            if (allsig) {
-                importSignatureKey->setEnabled(allunksig);
-                delSignKey->setEnabled(false);
-                m_popupsig->exec(pos);
-                return;
-            } else if (!keyDepth)
-            {
-                signKey->setEnabled(false);
-                refreshKey->setEnabled(false);
-                m_popupout->exec(pos);
-                return;
-            }
-            else
-            {
-                signKey->setEnabled(true);
-                refreshKey->setEnabled(true);
-            }
-        }
+	for (i = 0; i < cnt; ++i) {
+		KeyListViewItem *n = exportList.at(i);
 
-        if (sel->depth() != 0)
-        {
-            if (isSignature(sel))
-            {
-                 if (isSignatureUnknown(sel))
-                     importSignatureKey->setEnabled(true);
-                 else
-                     importSignatureKey->setEnabled(false);
-                 delSignKey->setEnabled(true);
-                 m_popupsig->exec(pos);
-                 return;
-            }
-            else
-            if (sel->itemType() == KeyListViewItem::Uat)
-                m_popupphoto->exec(pos);
-            else
-            if (sel->itemType() == KeyListViewItem::Uid) {
-                KeyListViewItem *parent = sel->parent();
-                setPrimUid->setVisible(parent->itemType() & KeyListViewItem::Secret);
-                m_popupuid->exec(pos);
-            }
-        }
-        else
-        {
-            keysList2->setSelected(sel, true);
-            if (sel->itemType() & KeyListViewItem::Group)
-                m_popupgroup->exec(pos);
-            else
-            {
-                QList<KeyListViewItem*> exportList = keysList2->selectedItems();
-                bool unksig = false;
+		t |= n->itemType();
+		allunksig &= isSignatureUnknown(n);
+	}
 
-                // find out if an item has unknown signatures. Only check if the item has been
-                // expanded before as expansion is very expensive and can take several seconds
-                // that will freeze the UI meanwhile.
-                for (int i = 0; i < exportList.count(); i++) {
-                   KeyListViewItem *k = exportList.at(i);
-                   QStringList l;
+	if (t & KeyListViewItem::Pair) {
+		// find out if an item has unknown signatures. Only check if the item has been
+		// expanded before as expansion is very expensive and can take several seconds
+		// that will freeze the UI meanwhile.
+		for (int i = 0; i < exportList.count(); i++) {
+			KeyListViewItem *k = exportList.at(i);
+			QStringList l;
 
-                   if (k->firstChild() == NULL) {
-                      unksig = true;
-                      break;
-                   }
-                   getMissingSigs(&l, k);
-                   if (!l.isEmpty()) {
-                      unksig = true;
-                      break;
-                   }
-                }
-                importAllSignKeys->setEnabled(unksig);
+			if (k->firstChild() == NULL) {
+				unksig = true;
+				break;
+			}
+			getMissingSigs(&l, k);
+			if (!l.isEmpty()) {
+				unksig = true;
+				break;
+			}
+		}
+		importAllSignKeys->setEnabled(unksig);
+	}
 
-                if (((sel->itemType() & KeyListViewItem::Pair) == KeyListViewItem::Pair) && (exportList.count() == 1))
-                    m_popupsec->exec(pos);
-                else
-                if ((sel->itemType() == KeyListViewItem::Secret) && (exportList.count() == 1))
-                    m_popuporphan->exec(pos);
-                else
-                    m_popuppub->exec(pos);
-            }
-        }
-    }
-    else
-        m_popupout->exec(pos);
+	if (t == KeyListViewItem::Sign) {
+		importSignatureKey->setEnabled(allunksig);
+		delSignKey->setEnabled( (cnt == 1) );
+		m_popupsig->exec(pos);
+	} else if ((t == KeyListViewItem::Uid) && (cnt == 1)) {
+		KeyListViewItem *parent = exportList.at(0)->parent();
+		setPrimUid->setVisible(parent->itemType() & KeyListViewItem::Secret);
+		m_popupuid->exec(pos);
+	} else if ((t == KeyListViewItem::Uat) && (cnt == 1)) {
+		m_popupphoto->exec(pos);
+	} else if ((t == KeyListViewItem::Pair) && (cnt == 1)) {
+		m_popupsec->exec(pos);
+	} else if ((t == KeyListViewItem::Secret) && (cnt == 1)) {
+		m_popuporphan->exec(pos);
+	} else if (t == KeyListViewItem::Group) {
+		delGroup->setEnabled( (cnt == 1) );
+		editCurrentGroup->setEnabled( (cnt == 1) );
+		m_popupgroup->exec(pos);
+	} else if (!(t & ~(KeyListViewItem::Pair | KeyListViewItem::Group))) {
+		signKey->setEnabled(!(t & KeyListViewItem::Group));
+		deleteKey->setEnabled(!(t & KeyListViewItem::Group));
+		m_popuppub->exec(pos);
+	} else {
+		m_popupout->exec(pos);
+	}
 }
 
 void KeysManager::slotrevoke(const QString &keyID, const QString &revokeUrl, const int reason, const QString &description)
@@ -1482,10 +1454,10 @@ void KeysManager::slotImportRevokeTxt(const QString &revokeText)
 void KeysManager::slotexportsec()
 {
     // export secret key
-    QString warn = i18n("Secret keys SHOULD NOT be saved in an unsafe place.\n"
-                        "If someone else can access this file, encryption with this key will be compromised!\nContinue key export?");
-    int result = KMessageBox::questionYesNo(this, warn, i18n("Warning"), KGuiItem(i18n("Export")), KGuiItem(i18n("Do Not Export")));
-    if (result != KMessageBox::Yes)
+    QString warn = i18n("<qt>Secret keys <b>should not</b> be saved in an unsafe place.<br/>"
+                        "If someone else can access this file, encryption with this key will be compromised!<br/>Continue key export?</qt>");
+    int result = KMessageBox::warningContinueCancel(this, warn);
+    if (result != KMessageBox::Continue)
         return;
     KeyListViewItem *item = keysList2->currentItem();
 
@@ -1508,7 +1480,8 @@ void KeysManager::slotexportsec()
         p.execute();
 
         if (fgpg.exists())
-            KMessageBox::information(this, i18n("Your PRIVATE key \"%1\" was successfully exported.\nDO NOT leave it in an insecure place.", url.path()));
+            KMessageBox::information(this, i18n("<qt>Your <b>private</b> key \"%1\" was successfully exported to<br/>%2 .<br/>"
+                                                "<b>Do not</b> leave it in an insecure place.</qt>", item->keyId(), url.path()));
         else
             KMessageBox::sorry(this, i18n("Your secret key could not be exported.\nCheck the key."));
     }
@@ -1541,7 +1514,7 @@ void KeysManager::slotexport()
 	QStringList klist;
 	for (int i = 0; i < exportList.count(); ++i) {
 		KeyListViewItem *item = static_cast<KeyListViewItem *>(exportList.at(i));
-	
+
 		if (item)
 			klist.append(item->keyId());
 	}
@@ -1612,7 +1585,9 @@ void KeysManager::slotexport()
                 p.execute();
 
                 if (fgpg.exists())
-                    KMessageBox::information(this, i18n("Your public key \"%1\" was successfully exported\n", expname));
+                    KMessageBox::information(this, i18np("<qt>The public key was successfully exported to<br/>%2</qt>",
+                                                         "<qt>The %1 public keys were successfully exported to<br/>%2</qt>",
+                                                         klist.count(), expname));
                 else
                     KMessageBox::sorry(this, i18n("Your public key could not be exported\nCheck the key."));
             }
@@ -1662,7 +1637,7 @@ void KeysManager::slotShowPhoto()
     p.startDetached();
 }
 
-void KeysManager::listsigns()
+void KeysManager::defaultAction()
 {
     // kDebug(2100) << "Edit -------------------------------" ;
     KeyListViewItem *cur = keysList2->currentItem();
@@ -1693,6 +1668,16 @@ void KeysManager::listsigns()
         return;
     }
 
+    if (cur->itemType() & KeyListViewItem::Pair)
+        keyproperties();
+}
+
+void KeysManager::keyproperties()
+{
+    KeyListViewItem *cur = keysList2->currentItem();
+    if (cur == NULL)
+        return;
+
     if (cur->itemType() == KeyListViewItem::Secret)
     {
         if (KMessageBox::questionYesNo(this, i18n("This key is an orphaned secret key (secret key without public key.) It is currently not usable.\n\n"
@@ -1705,7 +1690,7 @@ void KeysManager::listsigns()
     if (!key.isEmpty())
     {
         KgpgKeyInfo *opts = new KgpgKeyInfo(key, this);
-        connect(opts, SIGNAL(keyNeedsRefresh()), keysList2, SLOT(refreshselfkey()));
+        connect(opts, SIGNAL(keyNeedsRefresh(const QString &)), keysList2, SLOT(refreshcurrentkey(const QString &)));
         opts->exec();
         delete opts;
     }
@@ -1732,7 +1717,7 @@ void KeysManager::deleteGroup()
     if (!keysList2->currentItem() || (keysList2->currentItem()->itemType() != KeyListViewItem::Group))
         return;
 
-    int result = KMessageBox::warningContinueCancel(this, i18n("<qt>Are you sure you want to delete group <b>%1</b> ?</qt>", keysList2->currentItem()->text(0)), i18n("Warning"), KGuiItem(i18n("Delete"), "edit-delete"));
+    int result = KMessageBox::warningContinueCancel(this, i18n("<qt>Are you sure you want to delete group <b>%1</b> ?</qt>", keysList2->currentItem()->text(0)), QString(), KGuiItem(i18n("Delete"), "edit-delete"));
     if (result != KMessageBox::Continue)
         return;
 
@@ -1749,7 +1734,7 @@ void KeysManager::deleteGroup()
     QStringList groups = KgpgInterface::getGpgGroupNames(KGpgSettings::gpgConfigPath());
     KGpgSettings::setGroups(groups.join(","));
     keysList2->groupNb = groups.count();
-    changeMessage(i18n("%1 Keys, %2 Groups", keysList2->childCount()-keysList2->groupNb, keysList2->groupNb), 1);
+    changeMessage(keysList2->statusCountMessage(), 1);
 }
 
 void KeysManager::groupChange()
@@ -1758,10 +1743,24 @@ void KeysManager::groupChange()
     KeyListViewItem *item = static_cast<KeyListViewItem*>(gEdit->groupKeys->firstChild());
     while (item)
     {
-        selected += item->text(2);
+        selected += item->keyId();
         item = item->nextSibling();
     }
     KgpgInterface::setGpgGroupSetting(keysList2->currentItem()->text(0), selected,KGpgSettings::gpgConfigPath());
+    keysList2->currentItem()->setText(4, i18np("%1 key", "%1 keys", selected.count()));
+    item = keysList2->currentItem()->firstChild();
+    if (item)
+    {
+         bool o = keysList2->currentItem()->isOpen();
+
+         while (item) {
+             delete item;
+             item = keysList2->currentItem()->firstChild();
+        }
+        keysList2->expandGroup(keysList2->currentItem());
+        if (o)
+           keysList2->currentItem()->setOpen(true);
+    }
 }
 
 void KeysManager::createNewGroup()
@@ -1782,8 +1781,8 @@ void KeysManager::createNewGroup()
                 } else
                 if (groupList.at(i)->pixmap(2))
                 {
-                    if ((groupList.at(i)->pixmap(2)->serialNumber() == keysList2->trustgood.serialNumber()) ||
-                        (groupList.at(i)->pixmap(2)->serialNumber() == keysList2->trustultimate.serialNumber()))
+                    if ((groupList.at(i)->trust() == TRUST_FULL) ||
+                        (groupList.at(i)->trust() == TRUST_ULTIMATE))
                         keysGroup += groupList.at(i)->keyId();
                     else
                         badkeys += groupList.at(i)->text(0) + " (" + groupList.at(i)->text(1) + ") " + groupList.at(i)->keyId();
@@ -1815,7 +1814,7 @@ void KeysManager::createNewGroup()
             keysList2->setSelected(newgrp, true);
             keysList2->ensureItemVisible(newgrp);
             keysList2->groupNb = groups.count();
-            changeMessage(i18n("%1 Keys, %2 Groups", keysList2->childCount() - keysList2->groupNb, keysList2->groupNb), 1);
+            changeMessage(keysList2->statusCountMessage(), 1);
         }
         else
             KMessageBox::sorry(this, i18n("<qt>No valid or trusted key was selected. The group <b>%1</b> will not be created.</qt>", groupName));
@@ -1830,8 +1829,19 @@ void KeysManager::groupInit(const QStringList &keysGroup)
     for (QStringList::ConstIterator it = keysGroup.begin(); it != keysGroup.end(); ++it)
     {
         KeyListViewItem *item = keysList2->findItemByKeyId(QString(*it));
-        if (item != NULL)
-            gEdit->groupKeys->insertItem(item);
+        if (item != NULL) {
+            KeyListViewItem *n = new KeyListViewItem(gEdit->groupKeys, *item->getKey(), item->isDefault());
+            n->setText(2, item->text(6));
+
+            n = static_cast<KeyListViewItem *>(gEdit->availableKeys->firstChild());
+            while (n) {
+               if (*n->getKey() == *item->getKey()) {
+                   delete n;
+                   break;
+               }
+               n = n->nextSibling();
+            }
+        }
         else
             lostKeys += QString(*it);
 
@@ -1866,18 +1876,16 @@ void KeysManager::editGroup()
     if (!item)
         return;
 
-    if (item->pixmap(2))
-        if ((item->pixmap(2)->serialNumber() == keysList2->trustgood.serialNumber()) ||
-            (item->pixmap(2)->serialNumber() == keysList2->trustultimate.serialNumber()))
-            (void) new K3ListViewItem(gEdit->availableKeys, item->text(0), item->text(1), item->text(6));
-
-    while (item->nextSibling())
+    while (item)
     {
-        item = item->nextSibling();
         if (item->pixmap(2))
-            if ((item->pixmap(2)->serialNumber() == keysList2->trustgood.serialNumber()) ||
-                (item->pixmap(2)->serialNumber() == keysList2->trustultimate.serialNumber()))
-                (void) new K3ListViewItem(gEdit->availableKeys, item->text(0), item->text(1), item->text(6));
+            if ((item->trust() == TRUST_FULL) ||
+                (item->trust() == TRUST_ULTIMATE)) {
+                     KeyListViewItem *n = new KeyListViewItem(gEdit->availableKeys, *item->getKey(), item->isDefault());
+                     n->setText(2, item->text(6));
+            }
+
+        item = item->nextSibling();
     }
 
     keysGroup = KgpgInterface::getGpgGroupSetting(keysList2->currentItem()->text(0), KGpgSettings::gpgConfigPath());
@@ -1996,10 +2004,10 @@ void KeysManager::signatureResult(int success, KgpgInterface *interface)
         keysList2->refreshcurrentkey(signList.at(keyCount));
     else
     if (success == 1)
-        KMessageBox::sorry(this, i18n("<qt>Bad passphrase, key <b>%1</b> not signed.</qt>", signList.at(keyCount)->text(0) + i18n(" (") + signList.at(keyCount)->text(1) + i18n(")")));
+        KMessageBox::sorry(this, i18n("<qt>Bad passphrase, key <b>%1 (%2)</b> not signed.</qt>", signList.at(keyCount)->text(0), signList.at(keyCount)->text(1)));
     else
     if (success == 4)
-        KMessageBox::sorry(this, i18n("<qt>The key <b>%1</b> is already signed.</qt>", signList.at(keyCount)->text(0) + i18n(" (") + signList.at(keyCount)->text(1) + i18n(")")));
+        KMessageBox::sorry(this, i18n("<qt>The key <b>%1 (%2)</b> is already signed.</qt>", signList.at(keyCount)->text(0), signList.at(keyCount)->text(1)));
 
     keyCount++;
     signLoop();
@@ -2028,7 +2036,7 @@ void KeysManager::importallsignkey()
 	for (i = 0; i < sel.count(); i++) {
 		KeyListViewItem *cur = sel.at(i);
 		KeyListViewItem *item = cur->firstChild();
-		
+
 		if (item == NULL) {
 			cur->setOpen(true);
 			cur->setOpen(false);
@@ -2072,37 +2080,23 @@ void KeysManager::preimportsignkey()
     importsignkey(idlist);
 }
 
-bool KeysManager::importRemoteKey(const QString &keyID)
+bool KeysManager::importRemoteKey(const QString &keyIDs)
 {
-    kServer = new KeyServer(0, false, true);
-    kServer->slotSetText(keyID);
-    //kServer->page->Buttonimport->setDefault(true);
-    //kServer->page->tabWidget2->setTabEnabled(kServer->page->tabWidget2->page(1),false);
-    kServer->show();
-    kServer->raise();
-    connect(kServer, SIGNAL(importFinished(QString)), this, SLOT( dcopImportFinished()));
+	KGpgTransaction *xact = new KGpgTransaction();
 
-    return true;
+	QStringList kservers = KeyServer::getServerList();
+	if (kservers.isEmpty())
+		return false;
+	connect(xact, SIGNAL(receiveComplete(KGpgTransaction *)), this, SLOT(importRemoteFinished(KGpgTransaction *)));
+	xact->iface->downloadKeys(keyIDs.split(' '), kservers.first(), false, getenv("http_proxy"));
+
+	return true;
 }
 
-void KeysManager::dcopImportFinished()
+void KeysManager::importRemoteFinished(KGpgTransaction *t)
 {
-    if (kServer)
-        kServer = 0L;
-#ifdef __GNUC__
-#warning "kde4 dbus port it"
-#endif
-#if 0
-    QByteArray params;
-    QDataStream stream(&params, QIODevice::WriteOnly);
-
-    stream.setVersion(QDataStream::Qt_4_3);
-    stream << true;
-
-    kapp->dcopClient()->emitDCOPSignal("keyImported(bool)", params);
-#endif
-
-    refreshkey();
+	delete t;
+	keysList2->refreshAll();
 }
 
 void KeysManager::importsignkey(const QStringList &importKeyId)
@@ -2129,10 +2123,13 @@ void KeysManager::delsignkey()
     if (keysList2->currentItem() == 0)
         return;
 
-    if (keysList2->currentItem()->depth() > 1)
-    {
-        KMessageBox::sorry(this, i18n("Edit key manually to delete this signature."));
-        return;
+    QString uid;
+    KeyListViewItem *parent = keysList2->currentItem()->parent();
+    if (parent->itemType() == KeyListViewItem::Public)
+        uid = '1';
+    else {
+        Q_ASSERT(parent->itemType() == KeyListViewItem::Uid);
+        uid = parent->text(6);
     }
 
     QString signID;
@@ -2140,28 +2137,36 @@ void KeysManager::delsignkey()
     QString signMail;
     QString parentMail;
     KeyListViewItem *sitem = keysList2->currentItem();
-    KeyListViewItem *pitem = sitem->parent();
 
-    // open a key selection dialog (KgpgSelectSecretKey, see beginning of this file)
-    parentKey = pitem->keyId();
+    if (parent->depth() == 1)
+        parentKey = parent->parent()->keyId();
+    else
+        parentKey = parent->keyId();
     signID = sitem->keyId();
     parentMail = keysList2->currentItem()->parent()->text(0) + " (" + keysList2->currentItem()->parent()->text(1) + ')';
     signMail = keysList2->currentItem()->text(0) + " (" + keysList2->currentItem()->text(1) + ')';
 
+    parentMail = parent->text(0);
+    if (!parent->text(1).isEmpty())
+       parentMail += " &lt;" + parent->text(1) + "&gt;";
+    signMail = keysList2->currentItem()->text(0);
+    if (!keysList2->currentItem()->text(1).isEmpty())
+       signMail += " &lt;" + keysList2->currentItem()->text(1) + "&gt;";
+
     if (parentKey == signID)
     {
         KMessageBox::sorry(this, i18n("Edit key manually to delete a self-signature."));
         return;
     }
 
-    QString ask = i18n("<qt>Are you sure you want to delete signature<br /><b>%1</b> from key:<br /><b>%2</b>?</qt>", signMail, parentMail);
+    QString ask = i18n("<qt>Are you sure you want to delete signature<br /><b>%1</b><br />from user id <b>%2</b><br />of key: <b>%3</b>?</qt>", signMail, parentMail, parentKey);
 
     if (KMessageBox::questionYesNo(this, ask, QString(), KStandardGuiItem::del(), KStandardGuiItem::cancel()) != KMessageBox::Yes)
         return;
 
     KgpgInterface *delSignKeyProcess = new KgpgInterface();
     connect(delSignKeyProcess, SIGNAL(delsigfinished(bool)), this, SLOT(delsignatureResult(bool)));
-    delSignKeyProcess->KgpgDelSignature(parentKey, signID);
+    delSignKeyProcess->KgpgDelSignature(parentKey, uid, signID);
 }
 
 void KeysManager::delsignatureResult(bool success)
@@ -2185,19 +2190,27 @@ void KeysManager::slotedit()
 
     if (item == NULL)
         return;
-    if (item->depth() != 0)
+    if (!(item->itemType() & KeyListViewItem::Pair))
         return;
-    if (item->keyId() == NULL)
+    if (!terminalkey.isEmpty())
         return;
 
-    QProcess *kp = new QProcess(this);
+    KProcess *kp = new KProcess(this);
     KConfigGroup config(KGlobal::config(), "General");
-    QString terminalApp = config.readPathEntry("TerminalApplication","konsole");
-    QStringList args;
-    args << "-e" << KGpgSettings::gpgBinaryPath() <<"--no-secmem-warning" <<"--edit-key" << keysList2->currentItem()->keyId() << "help";
-    kp->start(terminalApp, args);
-    kp->waitForFinished();
-    keysList2->refreshcurrentkey(keysList2->currentItem());
+    *kp << config.readPathEntry("TerminalApplication","konsole");
+    *kp << "-e" << KGpgSettings::gpgBinaryPath() <<"--no-secmem-warning" <<"--edit-key" << keysList2->currentItem()->keyId() << "help";
+    terminalkey = keysList2->currentItem()->keyId();
+
+    connect(kp, SIGNAL(finished(int)), SLOT(slotEditDone(int)));
+    kp->start();
+}
+
+void KeysManager::slotEditDone(int exitcode)
+{
+    if (exitcode == 0)
+        keysList2->refreshcurrentkey(terminalkey);
+
+    terminalkey.clear();
 }
 
 void KeysManager::doFilePrint(const QString &url)
@@ -2230,34 +2243,32 @@ void KeysManager::deleteseckey()
     // delete a key
     QString res = keysList2->currentItem()->text(0) + " (" + keysList2->currentItem()->text(1) + ')';
     int result = KMessageBox::warningContinueCancel(this,
-                        i18n("<p>Delete <b>SECRET KEY</b> pair <b>%1</b>?</p>Deleting this key pair means you will never be able to decrypt files encrypted with this key again.", res),
-                        i18n("Warning"),
+                        i18n("<p>Delete <b>secret</b> key pair <b>%1</b>?</p>Deleting this key pair means you will never be able to decrypt files encrypted with this key again.", res),
+                        QString(),
                         KGuiItem(i18n("Delete"),"edit-delete"));
     if (result != KMessageBox::Continue)
         return;
 
-    QProcess *conprocess = new QProcess();
+    KProcess *conprocess = new KProcess();
     KConfigGroup config(KGlobal::config(), "General");
-    QString terminalApp = config.readPathEntry("TerminalApplication","konsole");
-    QStringList args;
-    args << "-e" << KGpgSettings::gpgBinaryPath() <<"--no-secmem-warning" << "--delete-secret-key" << keysList2->currentItem()->keyId();
-    connect(conprocess, SIGNAL(finished()), this, SLOT(reloadSecretKeys()));
-    conprocess->start(terminalApp, args);
+    *conprocess << config.readPathEntry("TerminalApplication","konsole");
+    *conprocess << "-e" << KGpgSettings::gpgBinaryPath() <<"--no-secmem-warning" << "--delete-secret-and-public-key" << keysList2->currentItem()->keyId();
+    connect(conprocess, SIGNAL(finished(int)), this, SLOT(reloadSecretKeys()));
+    conprocess->start();
 }
 
 void KeysManager::reloadSecretKeys()
 {
+	refreshkey();
 }
 
 void KeysManager::confirmdeletekey()
 {
     KeyListViewItem *ki = keysList2->currentItem();
 
-    if (ki->depth() != 0)
-    {
-	// this is only a public key
-        if ((ki->depth() == 1) && !(ki->itemType() & KeyListViewItem::Secret) && (ki->itemType() & KeyListViewItem::Public))
-            delsignkey();
+    // do not delete a key currently edited in terminal
+    if ((ki->keyId() == terminalkey) && (keysList2->selectedItems().count() == 1)) {
+        KMessageBox::error(this, i18n("Can not delete key <b>%1</b> while it is edited in terminal.", terminalkey), i18n("Delete key"));
         return;
     }
 
@@ -2286,7 +2297,7 @@ void KeysManager::confirmdeletekey()
                     secList += ki->text(0) + " (" + ki->text(1) + ")<br/>";
                     ki->setSelected(false);
                 }
-                else
+                else if (ki->keyId() != terminalkey)
                     keysToDelete += ki->text(0) + " (" + ki->text(1) + ')';
             }
 	}
@@ -2301,7 +2312,7 @@ void KeysManager::confirmdeletekey()
         if (keysToDelete.isEmpty())
             return;
 
-        int result = KMessageBox::warningContinueCancelList(this, i18np("<qt><b>Delete the following public key?</b></qt>", "<qt><b>Delete the following %1 public keys?</b></qt>", keysToDelete.count()), keysToDelete, i18n("Warning"), KStandardGuiItem::del());
+        int result = KMessageBox::warningContinueCancelList(this, i18np("<qt><b>Delete the following public key?</b></qt>", "<qt><b>Delete the following %1 public keys?</b></qt>", keysToDelete.count()), keysToDelete, QString(), KStandardGuiItem::del());
         if (result != KMessageBox::Continue)
             return;
         else
@@ -2332,9 +2343,7 @@ void KeysManager::deletekey()
 
     gp.execute();
 
-    for (int i = 0; i < exportList.count(); ++i)
-        if (exportList.at(i))
-            keysList2->refreshcurrentkey(exportList.at(i));
+    keysList2->refreshAll();
 
     if (keysList2->currentItem())
     {
@@ -2366,7 +2375,7 @@ void KeysManager::deletekey()
     else
         stateChanged("empty_list");
 
-    changeMessage(i18n("%1 Keys, %2 Groups", keysList2->childCount() - keysList2->groupNb, keysList2->groupNb), 1);
+    changeMessage(keysList2->statusCountMessage(), 1);
 }
 
 void KeysManager::slotPreImportKey()
@@ -2381,17 +2390,17 @@ void KeysManager::slotPreImportKey()
     dial->setMainWidget(page);
     page->newFilename->setWindowTitle(i18n("Open File"));
     page->newFilename->setMode(KFile::File);
-    page->resize(page->minimumSize());
-    dial->resize(dial->minimumSize());
+//     page->resize(page->minimumSize());
+//     dial->resize(dial->minimumSize());
 
     if (dial->exec() == QDialog::Accepted)
     {
-        changeMessage(i18n("Importing..."), 0, true);
         if (page->checkFile->isChecked())
         {
             QString impname = page->newFilename->url().url().simplified();
             if (!impname.isEmpty())
             {
+                changeMessage(i18n("Importing..."), 0, true);
                 // import from file
                 KgpgInterface *importKeyProcess = new KgpgInterface();
                 connect(importKeyProcess, SIGNAL(importKeyFinished(QStringList)), keysList2, SLOT(slotReloadKeys(QStringList)));
@@ -2404,6 +2413,7 @@ void KeysManager::slotPreImportKey()
             QString keystr = kapp->clipboard()->text(m_clipboardmode);
             if (!keystr.isEmpty())
             {
+                changeMessage(i18n("Importing..."), 0, true);
                 KgpgInterface *importKeyProcess = new KgpgInterface();
                 connect(importKeyProcess,SIGNAL(importKeyFinished(QStringList)),keysList2,SLOT(slotReloadKeys(QStringList)));
                 connect(importKeyProcess,SIGNAL(importKeyOrphaned()),keysList2,SLOT(slotReloadOrphaned()));
@@ -2420,4 +2430,15 @@ void KeysManager::refreshkey()
     m_listviewsearch->updateSearch(m_listviewsearch->text());
 }
 
+KGpgTransaction::KGpgTransaction()
+	: iface(new KgpgInterface())
+{
+	connect(iface, SIGNAL(downloadKeysFinished(QList<int>, QStringList, bool, QString, KgpgInterface*)), this, SLOT(slotDownloadKeysFinished(QList<int>, QStringList, bool, QString, KgpgInterface*)));
+}
+
+void KGpgTransaction::slotDownloadKeysFinished(QList<int>, QStringList, bool, QString, KgpgInterface*)
+{
+	emit receiveComplete(this);
+}
+
 #include "keysmanager.moc"
