@@ -48,7 +48,6 @@
 #include <k3activelabel.h>
 #include <KCmdLineArgs>
 #include <KMessageBox>
-#include <KIconLoader>
 #include <KFileDialog>
 #include <kdeversion.h>
 #include <KShortcut>
@@ -73,6 +72,7 @@
 #include <KIcon>
 #include <kdefakes.h>
 
+#include "images.h"
 #include "selectsecretkey.h"
 #include "kgpgeditor.h"
 #include "kgpgsettings.h"   // automatically created by compilation
@@ -83,6 +83,7 @@
 #include "kgpglibrary.h"
 #include "kgpg_interface.h"
 
+using namespace KgpgCore;
 
 static QString getGpgHome()
 {
@@ -148,7 +149,7 @@ MyView::~MyView()
 void MyView::clipEncrypt()
 {
     if (kapp->clipboard()->text(clipboardMode).isEmpty())
-        KPassivePopup::message(i18n("Clipboard is empty."), QString(), KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop), trayIcon);
+        KPassivePopup::message(i18n("Clipboard is empty."), QString(), Images::kgpg(), trayIcon);
     else
     {
         KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(0, 0, false, true, goDefaultKey);
@@ -161,7 +162,7 @@ void MyView::clipEncrypt()
 
             if (!dialog->getCustomOptions().isEmpty())
                 if (KGpgSettings::allowCustomEncryptionOptions())
-                    options << dialog->getCustomOptions().split(" ");
+                    options << dialog->getCustomOptions().split(" ", QString::SkipEmptyParts);
 
             encryptClipboard(dialog->selectedKeys(), options, dialog->getShred(), dialog->getSymmetric());
         }
@@ -193,7 +194,7 @@ void MyView::clipSign(bool openEditor)
         kgpgtxtedit->show();
     }
     else
-        KPassivePopup::message(i18n("Clipboard is empty."), QString(), KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop), trayIcon);
+        KPassivePopup::message(i18n("Clipboard is empty."), QString(), Images::kgpg(), trayIcon);
 }
 
 void MyView::encryptDroppedFile()
@@ -239,7 +240,7 @@ void MyView::encryptDroppedFolder()
 
         if (!dialog->getCustomOptions().isEmpty())
             if (KGpgSettings::allowCustomEncryptionOptions())
-                options << dialog->getCustomOptions().split(" ");
+                options << dialog->getCustomOptions().split(" ", QString::SkipEmptyParts);
 
         encryptClipboard(dialog->selectedKeys(), options, dialog->getShred(), dialog->getSymmetric());
     }
@@ -307,7 +308,7 @@ void MyView::startFolderEncode(const QStringList &selec, const QStringList &encr
     }
 
     pop = new KPassivePopup();
-    pop->setView(i18n("Processing folder compression and encryption"),i18n("Please wait..."), KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop));
+    pop->setView(i18n("Processing folder compression and encryption"),i18n("Please wait..."), Images::kgpg());
     pop->setAutoDelete(false);
     pop->show();
     kapp->processEvents();
@@ -645,7 +646,7 @@ void MyView::droppedtext (const QString &inputText, bool allowEncrypt)
 
     if (inputText.startsWith("-----BEGIN PGP PUBLIC KEY"))
     {
-        int result = KMessageBox::warningContinueCancel(0,i18n("<p>The dropped text is a public key.<br />Do you want to import it ?</p>"), i18n("Warning"));
+        int result = KMessageBox::warningContinueCancel(0,i18n("<p>The dropped text is a public key.<br />Do you want to import it ?</p>"));
         if (result == KMessageBox::Cancel)
             return;
         else
@@ -710,6 +711,8 @@ void MyView::readOptions()
             if (!groups.isEmpty())
                     KGpgSettings::setGroups(groups.join(","));
         }
+
+        trayIcon->setVisible(KGpgSettings::showSystray());
     }
 }
 
@@ -719,7 +722,7 @@ void MyView::firstRun()
     QStringList args;
     args << "--no-tty" << "--list-secret-keys";
     createConfigProc->start("gpg", args);// start gnupg so that it will create a config file
-    createConfigProc->waitForFinished(); 
+    createConfigProc->waitForFinished();
     startWizard();
 }
 
@@ -728,7 +731,7 @@ void MyView::startWizard()
     kDebug(2100) << "Starting Wizard" ;
 
     wiz = new KgpgWizard(0);
-    
+
     QString gpgHome(getGpgHome());
     QString confPath = gpgHome + "options";
 
@@ -739,7 +742,7 @@ void MyView::startWizard()
         {
             if (KMessageBox::questionYesNo(0, i18n("<qt><b>The GnuPG configuration file was not found</b>. Please make sure you have GnuPG installed. Should KGpg try to create a config file ?</qt>"), QString(), KGuiItem(i18n("Create Config")), KGuiItem(i18n("Do Not Create"))) == KMessageBox::Yes)
             {
-                confPath = gpgHome + "options";
+                confPath = gpgHome + "gpg.conf";
                 QFile file(confPath);
                 if (file.open(QIODevice::WriteOnly))
                 {
@@ -767,46 +770,28 @@ void MyView::startWizard()
     wiz->kURLRequester2->setURL(KGlobalSettings::desktopPath());
         wiz->kURLRequester2->setMode(2);*/
 
-    FILE *fp,*fp2;
-    QString tst;
-    QString tst2;
-    QString name;
-    QString trustedvals = "idre-";
     QString firstKey = QString();
-    char line[300];
-    bool counter = false;
 
-    fp = popen("gpg --no-tty --with-colon --list-secret-keys", "r");
-    while (fgets(line, sizeof(line), fp))
-    {
-        tst = line;
-        if (tst.startsWith("sec"))
-        {
-            name = KgpgInterface::checkForUtf8(tst.section(':', 9, 9));
-            if (!name.isEmpty())
-            {
-                fp2 = popen("gpg --no-tty --with-colon --list-keys " + QFile::encodeName(tst.section(':',4,4)), "r");
-                while (fgets( line, sizeof(line), fp2))
-                {
-                    tst2 = line;
-                    if (tst2.startsWith("pub") && !trustedvals.contains(tst2.section(':',1,1)))
-                    {
-                        counter = true;
-                        wiz->CBdefault->addItem(tst.section(':', 4, 4).right(8) + ": " + name);
-                        if (firstKey.isEmpty())
-                            firstKey=tst.section(':',4,4).right(8)+": "+name;
-                        break;
-                    }
-                }
-                pclose(fp2);
-            }
-        }
+    KgpgInterface *interface = new KgpgInterface();
+    KgpgKeyList secretlist = interface->readSecretKeys();
+
+    KgpgKeyList publiclist = interface->readPublicKeys(true, secretlist);
+    delete interface;
+
+    for (int i = 0; i < publiclist.size(); ++i) {
+        KgpgKey k = publiclist.at(i);
+
+        QString s = k.id() + ": " + k.name() + " <" + k.email() + '>';
+
+        wiz->CBdefault->addItem(s);
+        if (firstKey.isEmpty())
+            firstKey = s;
     }
-    pclose(fp);
+
     wiz->CBdefault->setCurrentItem(firstKey);
 
     //connect(wiz->pushButton4,SIGNAL(clicked()),this,SLOT(slotGenKey()));
-    if (!counter)
+    if (!firstKey.isEmpty())
         connect(wiz->finishButton(),SIGNAL(clicked()),this,SLOT(slotGenKey()));
     else
     {
@@ -825,26 +810,25 @@ void MyView::startWizard()
 
 void MyView::slotWizardChange()
 {
-    QString tst,name;
-    char line[300];
-    FILE *fp;
-
     if (wiz->indexOf(wiz->currentPage()) == 2)
     {
-        QString defaultID = KgpgInterface::getGpgSetting("default-key", wiz->kURLRequester1->url().path());
-        if (defaultID.isEmpty())
+        QString tst,name;
+        KgpgInterface *iface = new KgpgInterface();
+        QString defaultID = iface->getGpgSetting("default-key", wiz->kURLRequester1->url().path());
+
+        if (defaultID.isEmpty()) {
+            delete iface;
             return;
-        fp = popen("gpg --no-tty --with-colon --list-secret-keys " + QFile::encodeName(defaultID), "r");
-        while (fgets( line, sizeof(line), fp))
-        {
-            tst = line;
-            if (tst.startsWith("sec"))
-            {
-                name = KgpgInterface::checkForUtf8(tst.section(':', 9, 9));
-                wiz->CBdefault->setCurrentItem(tst.section(':', 4, 4).right(8) + ": " + name);
-            }
         }
-        pclose(fp);
+        KgpgKeyList secl = iface->readSecretKeys(QStringList(defaultID));
+        delete iface;
+
+        if (secl.isEmpty())
+            return;
+
+        KgpgKey k = secl.at(0);
+
+        wiz->CBdefault->setCurrentItem(k.id() + ": " + k.name() + " <" + k.email() + '>');
     }
 }
 
@@ -911,7 +895,7 @@ void MyView::encryptClipboard(QStringList selec, QStringList encryptOptions, con
 {
     if (kapp->clipboard()->text(clipboardMode).isEmpty())
     {
-        KPassivePopup::message(i18n("Clipboard is empty."), QString(), KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop), trayIcon);
+        KPassivePopup::message(i18n("Clipboard is empty."), QString(), Images::kgpg(), trayIcon);
         return;
     }
 
@@ -939,7 +923,7 @@ void MyView::slotPassiveClip()
     newtxt.replace(QRegExp("\n"), "<br>");
 
     pop = new KPassivePopup();
-    pop->setView(i18n("Encrypted following text:"), newtxt, KIconLoader::global()->loadIcon("kgpg", K3Icon::Desktop));
+    pop->setView(i18n("Encrypted following text:"), newtxt, Images::kgpg());
     pop->setTimeout(3200);
     pop->show();
     QRect qRect(QApplication::desktop()->screenGeometry());
@@ -1034,6 +1018,7 @@ KgpgAppletApp::KgpgAppletApp()
              : KUniqueApplication()
 {
     running = false;
+    kgpg_applet = NULL;
 }
 
 KgpgAppletApp::~KgpgAppletApp()
@@ -1096,8 +1081,13 @@ int KgpgAppletApp::newInstance()
         connect(kgpg_applet->w,SIGNAL(createNewKey()),s_keyManager,SLOT(slotGenerateKey()));
         connect(s_keyManager,SIGNAL(fontChanged(QFont)),kgpg_applet->w,SIGNAL(setFont(QFont)));
         connect(kgpg_applet->w,SIGNAL(importedKeys(QStringList)),s_keyManager->keysList2,SLOT(slotReloadKeys(QStringList)));
-        kgpg_applet->show();
 
+        if (KGpgSettings::showSystray()) {
+            kgpg_applet->show();
+        } else {
+            kgpg_applet->setVisible(false);
+            kgpg_applet->parentWidget()->show();
+        }
 
         if (!gpgPath.isEmpty())
         {
@@ -1125,6 +1115,7 @@ int KgpgAppletApp::newInstance()
     if (args->isSet("d") != 0)
     {
        s_keyManager->slotOpenEditor();
+       s_keyManager->hide();
     }
     else
     if (args->count() > 0)
