@@ -29,6 +29,8 @@
 class KTemporaryFile;
 class K3Process;
 class K3ProcIO;
+class KProcess;
+class GPGProc;
 
 /**
  * This class is the interface for gpg.
@@ -61,8 +63,6 @@ public:
     static bool getGpgBoolSetting(const QString &name, const QString &configfile);
     static void setGpgBoolSetting(const QString &name, const bool &enable, const QString &url);
 
-    static int checkUID(const QString &keyid);
-
 /************** function to send a passphrase to gpg **************/
 private:
     /**
@@ -89,15 +89,14 @@ private:
 
 /************** extract public keys **************/
 signals:
-    void readPublicKeysStarted(KgpgInterface*);
     void readPublicKeysFinished(KgpgCore::KgpgKeyList, KgpgInterface*);
 
 public slots:
     KgpgCore::KgpgKeyList readPublicKeys(const bool &block = false, const QStringList &ids = QStringList(), const bool &withsigs = false);
 
 private slots:
-    void readPublicKeysProcess(K3ProcIO *p);
-    void readPublicKeysFin(K3Process *p, const bool &block = false);
+    void readPublicKeysProcess(GPGProc *p);
+    void readPublicKeysFin(GPGProc *p, const bool &block = false);
 
 private:
     int m_numberid;
@@ -111,9 +110,10 @@ private:
 /************** extract secret keys **************/
 public slots:
     KgpgCore::KgpgKeyList readSecretKeys(const QStringList &ids = QStringList());
+    KgpgCore::KgpgKeyList readJoinedKeys(const KgpgCore::KgpgKeyTrust &trust, const QStringList &ids = QStringList());
 
 private slots:
-    void readSecretKeysProcess(K3ProcIO *p);
+    void readSecretKeysProcess(GPGProc *p);
 
 private:
     bool m_secretactivate;
@@ -390,14 +390,9 @@ public slots:
     /**
      * This method changes the trust of a key
      * @param keyid the id of the key
-     * @param keytrust the new trust,
-     * Don't know = 1,
-     * Do NOT trust = 2,
-     * Marginally = 3,
-     * Fully = 4,
-     * Ultimately = 5.
+     * @param keytrust the new trust
      */
-    void changeTrust(const QString &keyid, const int &keytrust);
+    void changeTrust(const QString &keyid, const KgpgCore::KgpgKeyOwnerTrust &keytrust);
 
 private slots:
     void changeTrustProcess(K3ProcIO *p);
@@ -411,14 +406,13 @@ private:
 
 /************** change disable key **************/
 signals:
-    void changeDisableFinished(KgpgInterface*);
+    void changeDisableFinished(KgpgInterface*, int res);
 
 public slots:
     void changeDisable(const QString &keyid, const bool &ison);
 
 private slots:
-    void changeDisableProcess(K3ProcIO *p);
-    void changeDisableFin(K3Process *p);
+    void changeDisableFin(int res);
 
 /************************************************/
 
@@ -628,11 +622,61 @@ private:
 /******************************************/
 
 
+/************** download keys from keys server **************/
+signals:
+    /*
+    0 : keys processed
+    1 : keys without id
+    2 : keys imported
+    3 : RSA keys
+    4 : unchanged
+    5 : Uid imported
+    6 : Subkey imported
+    7 : Sign imported
+    8 : Revocation imported
+    9 : secret keys processed
+    10 : secret keys imported
+    11 : secret keys unchanged
+    12 : secret keys not imported
+    */
+    void downloadKeysFinished(QList<int>, QStringList, bool, QString, KgpgInterface*);
+    void downloadKeysAborted(KgpgInterface*);
+
+public slots:
+    void downloadKeys(const QStringList &keys, const QString &keyserver, const bool &refresh, const QString &proxy = "");
+    void downloadKeysAbort();
+
+private slots:
+    void downloadKeysProcess(K3ProcIO *p);
+    void downloadKeysFin(K3Process *p);
+
+private:
+    K3ProcIO *m_downloadprocess;
+    QString m_downloadkeys;
+    QString m_downloadkeys_log;
+
+/***********************************************************/
 
 
 
+/************** upload keys to keys server **************/
+signals:
+    void uploadKeysFinished(QString, KgpgInterface*);
+    void uploadKeysAborted(KgpgInterface*);
 
+public slots:
+    void uploadKeys(const QStringList &keys, const QString &keyserver, const QString &attributes, const QString &proxy = "");
+    void uploadKeysAbort();
 
+private slots:
+    void uploadKeysProcess(K3ProcIO *p);
+    void uploadKeysFin(K3Process *p);
+
+private:
+    K3ProcIO *m_uploadprocess;
+    QString m_uploadkeys_log;
+
+/********************************************************/
 
 
 
@@ -674,7 +718,7 @@ public slots:
      * @param keyID QString the ID of the key
      * @param signKeyID QString the ID of the signature key
      */
-    void KgpgDelSignature(const QString &keyID, QString signKeyID);
+    void KgpgDelSignature(const QString &keyID, const QString &uid, QString signKeyID);
 
     void KgpgRevokeKey(const QString &keyID, const QString &revokeUrl, const int reason, const QString &description);
     void revokeover(K3Process *);
@@ -697,6 +741,11 @@ private slots:
      */
     void delsignover(K3Process *p);
 
+    /**
+     * Finds the offset of the given signatures to a uid
+     */
+    void findSigns(const QString &keyID, const QStringList &ids, const QString &uid, QList<int> *res);
+
     /**
      * Checks output of the import process
      */
@@ -757,13 +806,15 @@ private:
     QString m_partialline;
     bool m_ispartial;
     QString message;
+    QString tmp_message;
     QString userIDs;
     QString log;
     bool encok;                 // encrypt ok
     bool decok;                 // decrypt ok
     bool badmdc;                // bad mdc
     bool badpassword;           // bad password
-    static K3ProcIO *gpgProc(const int statusfd = -1, const int cmdfd = -1);
+    KProcess *editprocess;
+    static K3ProcIO *gpgProc(const int &statusfd = -1, const int &cmdfd = -1);
 
     /**
      * @internal structure for communication
