@@ -32,7 +32,6 @@
 #include <KDesktopFile>
 #include <KColorButton>
 #include <KMessageBox>
-#include <KIconLoader>
 #include <KFileDialog>
 #include <KFontDialog>
 #include <KLineEdit>
@@ -42,11 +41,14 @@
 #include <KProcess>
 #include <kdefakes.h>
 
+#include "images.h"
 #include "kgpgsettings.h"
 
 // #include "conf_decryption.h"
 #include "conf_encryption.h"
 
+using namespace KgpgCore;
+
 //   main window
 kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
            : KConfigDialog(parent, name, KGpgSettings::self())
@@ -75,6 +77,8 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
 	defaultHomePath = KUrl::fromPath(gpgConfigPath).directory(KUrl::AppendTrailingSlash);
 	defaultBinPath = KGpgSettings::gpgBinaryPath();
 
+	m_showsystray = KGpgSettings::showSystray();
+
     kDebug(2100) << "Adding pages" ;
     m_page1 = new Encryption();
     m_page2 = new Decryption();
@@ -93,8 +97,8 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
     m_page7->shredInfo->setText(i18n( "<qt><p>You must be aware that <b>shredding is not secure</b> on all file systems, and that parts of the file may have been saved in a temporary file or in the spooler of your printer if you previously opened it in an editor or tried to print it. Only works on files (not on folders).</p></qt>"));
     m_page7->groupShred->adjustSize();
 
-    pixkeySingle = KIconLoader::global()->loadIcon("kgpg_key1", K3Icon::Small, 20);
-    pixkeyDouble = KIconLoader::global()->loadIcon("kgpg_key2", K3Icon::Small, 20);
+    pixkeySingle = Images::single();
+    pixkeyDouble = Images::pair();
     addPage(m_page1, i18n("Encryption"), "encrypted");
     addPage(m_page2, i18n("Decryption"), "decrypted");
     addPage(m_page3, i18n("Appearance"), "looknfeel");
@@ -117,6 +121,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
     connect(m_page6->server_default, SIGNAL(clicked()), this, SLOT(slotDefaultKeyServer()));
     connect(m_page6->ServerBox, SIGNAL(currentChanged(Q3ListBoxItem *)), this, SLOT(updateButtons()));
     connect(m_page7->pushShredder, SIGNAL(clicked ()), this, SIGNAL(installShredder()));
+    connect(m_page7->kcfg_ShowSystray, SIGNAL(toggled(bool)), this, SLOT(updateButtons()));
 
     keyUltimate = KGpgSettings::colorUltimate();
     keyGood = KGpgSettings::colorGood();
@@ -404,6 +409,9 @@ void kgpgOptions::updateSettings()
     if (keyRev != m_page3->kcfg_ColorRev->color())
         emit refreshTrust(RevColor, m_page3->kcfg_ColorRev->color());
 
+    m_showsystray = m_page7->kcfg_ShowSystray->isChecked();
+    KGpgSettings::setShowSystray(m_showsystray);
+
     KGpgSettings::self()->writeConfig();
     m_config->sync();
     emit settingsUpdated();
@@ -411,70 +419,33 @@ void kgpgOptions::updateSettings()
 
 void kgpgOptions::listKeys()
 {
-    // update display of keys in ComboBox
-    QString line;
-    QString name;
-    QString trustedvals = "idre-";
-    QString issec;
-    int counter = 0;
+	KgpgInterface *iface = new KgpgInterface;
+	KgpgCore::KgpgKeyList keys = iface->readJoinedKeys(KgpgCore::TRUST_MARGINAL);
+	delete iface;
 
-    KProcess *p = new KProcess();
-    *p << KGpgSettings::gpgBinaryPath() << "--no-secmem-warning" << "--no-tty" << "--with-colon" << "--list-secret-keys";
-    p->setOutputChannelMode(KProcess::MergedChannels);
-    p->execute();
+	if (keys.size() == 0) {
+		ids += QString("0");
+		m_page1->file_key->addItem(i18nc("no key available", "none"));
+		m_page1->always_key->addItem(i18nc("no key available", "none"));
+	} else {
+		for (int i = 0; i < keys.size(); i++) {
+			KgpgCore::KgpgKey key = keys.at(i);
 
-    while (p->canReadLine())
-    {
-        line = QString::fromLocal8Bit(p->readLine());
-        if (line.startsWith("sec"))
-            issec += line.section(':', 4, 4);
-    }
+			names += key.name();
+			ids += key.id();
+			QString text = key.id() + ": " + key.name() + " <" + key.email() + '>';
+			if (key.id() == alwaysKeyID)
+				alwaysKeyName = text;
 
-    delete p;
-
-    p = new KProcess();
-    *p << KGpgSettings::gpgBinaryPath() << "--no-tty" << "--with-colon" << "--list-keys";
-    p->setOutputChannelMode(KProcess::MergedChannels);
-    p->execute();
-
-    while (p->canReadLine())
-    {
-        line = QString::fromLocal8Bit(p->readLine());
-        if (line.startsWith("pub"))
-        {
-            name = KgpgInterface::checkForUtf8(line.section(':', 9, 9));
-            if ((!name.isEmpty()) && !trustedvals.contains(line.section(':', 1, 1) ) )
-            {
-                counter++;
-                //name=name.section('<',-1,-1);
-                //  name=name.section('>',0,0);
-                names += name;
-                ids += line.section(':', 4, 4);
-                if (line.section(':', 4, 4).right(8) == alwaysKeyID)
-                    alwaysKeyName = line.section(':', 4, 4).right(8) + ':' + name;
-
-                if (issec.contains(line.section(':', 4, 4).right(8), Qt::CaseInsensitive ) )
-                {
-                    m_page1->file_key->addItem(pixkeyDouble, line.section(':', 4, 4).right(8) + ':' + name);
-                    m_page1->always_key->addItem(pixkeyDouble, line.section(':', 4, 4).right(8) + ':' + name);
-                }
-                else
-                {
-                    m_page1->file_key->addItem(pixkeySingle, line.section(':', 4, 4).right(8) + ':' + name);
-                    m_page1->always_key->addItem(pixkeySingle, line.section(':', 4, 4).right(8) + ':' + name);
-                }
-            }
-        }
-    }
-
-    delete p;
-
-    if (counter == 0)
-    {
-        ids += QString("0");
-        m_page1->file_key->addItem(i18nc("no key available", "none"));
-        m_page1->always_key->addItem(i18nc("no key available", "none"));
-    }
+			if (key.secret()) {
+				m_page1->file_key->addItem(pixkeyDouble, text);
+				m_page1->always_key->addItem(pixkeyDouble, text);
+			} else {
+				m_page1->file_key->addItem(pixkeySingle, text);
+				m_page1->always_key->addItem(pixkeySingle, text);
+			}
+		}
+	}
 }
 
 void kgpgOptions::slotInstallDecrypt(const QString &mimetype)
@@ -556,6 +527,9 @@ bool kgpgOptions::hasChanged()
     if (currList != serverList)
         return true;
 
+    if (m_page7->kcfg_ShowSystray->isChecked() != m_showsystray)
+        return true;
+
     return false;
 }
 
@@ -584,6 +558,9 @@ bool kgpgOptions::isDefault()
     if (currList != defaultServerList)
         return false;
 
+    if (m_page7->kcfg_ShowSystray->isChecked() != m_showsystray)
+        return false;
+
     return true;
 }
 
