@@ -1973,7 +1973,8 @@ void CHexViewWidget::paintText( const QRect &rect, bool expand )
     {
       h = yMax > lineHeight ? lineHeight : yMax;
     }
-    bitBlt( this, r.x(), r.y()+s, &mTextBuffer, r.x(), d, r.width(), h );
+    QPainter m_r( this );
+    m_r.drawPixmap( QPoint( r.x(), r.y()+s ), mTextBuffer, QRect( r.x(), d, r.width(), h ) );
 
     s       += h;
     yMax    -= h;
@@ -1990,6 +1991,7 @@ void CHexViewWidget::paintCursor( int cursorMode )
   QPainter paint;
   paint.begin( &mTextBuffer );
   paint.setFont( mHexBuffer->font() );
+  QPainter m_p( this );
 
   int f = frameWidth();
 
@@ -2002,30 +2004,31 @@ void CHexViewWidget::paintCursor( int cursorMode )
     mHexBuffer->drawText( paint, line, startX(), p.x, p.x + p.w );
     if( p.y + p.h + f > contentsRect().bottom() )
       p.h = contentsRect().bottom() - p.y - f + 1;
-    bitBlt( this, p.x+f, p.y+f, &mTextBuffer, p.x, 0, p.w, p.h );
+      m_p.drawPixmap( QPoint( p.x+f, p.y+f ), mTextBuffer, QRect( p.x, 0, p.w, p.h ) );
 
     mHexBuffer->prevCursor( CHexBuffer::edit_secondary, p );
     mHexBuffer->drawText( paint, line, startX(), p.x, p.x + p.w );
     if( p.y + p.h + f > contentsRect().bottom() )
       p.h = contentsRect().bottom() - p.y - f + 1;
-    bitBlt( this, p.x+f, p.y+f, &mTextBuffer, p.x, 0, p.w, p.h );
+      m_p.drawPixmap( QPoint( p.x+f, p.y+f ), mTextBuffer, QRect( p.x, 0, p.w, p.h ) );
   }
   else
   {
     int line = mHexBuffer->cursorLine();
     SCursorPosition p;
+    QPainter m_p( this );
 
     mHexBuffer->currCursor( CHexBuffer::edit_primary, p );
     mHexBuffer->drawText( paint, line, startX(), p.x, p.x + p.w );
     if( p.y + p.h + f > contentsRect().bottom() )
       p.h = contentsRect().bottom() - p.y - f + 1;
-    bitBlt( this, p.x+f, p.y+f, &mTextBuffer, p.x, 0, p.w, p.h );
+      m_p.drawPixmap( QPoint( p.x+f, p.y+f ), mTextBuffer, QRect( p.x, 0, p.w, p.h ) );
 
     mHexBuffer->currCursor( CHexBuffer::edit_secondary, p );
     mHexBuffer->drawText( paint, line, startX(), p.x, p.x + p.w );
     if( p.y + p.h + f > contentsRect().bottom() )
       p.h = contentsRect().bottom() - p.y - f + 1;
-    bitBlt( this, p.x+f, p.y+f, &mTextBuffer, p.x, 0, p.w, p.h );
+      m_p.drawPixmap( QPoint( p.x+f, p.y+f ), mTextBuffer, QRect( p.x, 0, p.w, p.h ) );
   }
 
   paint.end();
