@@ -111,7 +111,7 @@ void COptionDialog::setupLayoutPage( void )
 
   mLayoutPage = new KPageWidgetItem( new QFrame(), i18n("Layout") );
   mLayoutPage->setHeader( i18n("Data Layout in Editor" ) );
-  mLayoutPage->setIcon( KIcon( BarIcon("khexedit", K3Icon::SizeMedium ) ));
+  mLayoutPage->setIcon( KIcon( BarIcon("khexedit", KIconLoader::SizeMedium ) ));
   addPage( mLayoutPage );
 
   QGridLayout *gbox = new QGridLayout( mLayoutPage->widget() );
@@ -275,7 +275,7 @@ void COptionDialog::setupCursorPage( void )
 
   KPageWidgetItem *mCursorPage = new KPageWidgetItem( new QFrame(), i18n("Cursor") );
   mCursorPage->setHeader( i18n("Cursor Behavior (only valid for editor)" ) );
-  mCursorPage->setIcon(KIcon(  BarIcon("mouse", K3Icon::SizeMedium ) ));
+  mCursorPage->setIcon(KIcon(  BarIcon("mouse", KIconLoader::SizeMedium ) ));
   addPage( mCursorPage );
 
   QVBoxLayout *topLayout = new QVBoxLayout( mCursorPage->widget() );
@@ -346,7 +346,7 @@ void COptionDialog::setupColorPage( void )
 
   KPageWidgetItem *mColorPage = new KPageWidgetItem( new QFrame(), i18n("Colors") );
   mColorPage->setHeader( i18n("Editor Colors (system selection color is always used)" ) );
-  mColorPage->setIcon(KIcon(  BarIcon("colorize", K3Icon::SizeMedium ) ));
+  mColorPage->setIcon(KIcon(  BarIcon("colorize", KIconLoader::SizeMedium ) ));
   addPage( mColorPage );
 
   QVBoxLayout *topLayout = new QVBoxLayout( mColorPage->widget() );
@@ -402,7 +402,7 @@ void COptionDialog::setupFontPage( void )
 
   KPageWidgetItem *mFontPage = new KPageWidgetItem( new QFrame(), i18n("Font") );
   mFontPage->setHeader( i18n("Font Selection (editor can only use a fixed font)") );
-  mFontPage->setIcon(KIcon(  BarIcon("fonts", K3Icon::SizeMedium ) ) );
+  mFontPage->setIcon(KIcon(  BarIcon("fonts", KIconLoader::SizeMedium ) ) );
   addPage( mFontPage );
 
   QVBoxLayout *topLayout = new QVBoxLayout( mFontPage->widget() );
@@ -461,7 +461,7 @@ void COptionDialog::setupFilePage( void )
 
   KPageWidgetItem *mFilePage = new KPageWidgetItem( new QFrame(), i18n("Files") );
   mFilePage->setHeader( i18n("File Management") );
-  mFilePage->setIcon(KIcon(  BarIcon("kmultiple", K3Icon::SizeMedium ) ) );
+  mFilePage->setIcon(KIcon(  BarIcon("kmultiple", KIconLoader::SizeMedium ) ) );
   addPage( mFilePage );
 
   QVBoxLayout *topLayout = new QVBoxLayout( mFilePage->widget() );
@@ -559,7 +559,7 @@ void COptionDialog::setupMiscPage( void )
 
   KPageWidgetItem *mMiscPage = new KPageWidgetItem( new QFrame(), i18n("Miscellaneous") );
   mMiscPage->setHeader( i18n("Various Properties") );
-  mMiscPage->setIcon(KIcon(  BarIcon("gear", K3Icon::SizeMedium ) ) );
+  mMiscPage->setIcon(KIcon(  BarIcon("gear", KIconLoader::SizeMedium ) ) );
   addPage( mMiscPage );
 
   QVBoxLayout *topLayout = new QVBoxLayout( mMiscPage->widget() );
