@@ -305,7 +305,6 @@ KJotsMain::KJotsMain()
     KStandardAction::preferences(this, SLOT(configure()), actionCollection());
 
     bookmarkMenu = actionCollection()->add<KActionMenu>("bookmarks");
-    bookmarkMenu->setIcon(KIcon("bookmarks"));
     bookmarkMenu->setText(i18n("&Bookmarks"));
     KJotsBookmarks* bookmarks = new KJotsBookmarks(bookshelf);
     /*KBookmarkMenu *bmm =*/ new KBookmarkMenu(
@@ -1055,7 +1054,7 @@ void KJotsMain::saveToFile(KJotsMain::ExportType type)
             doc.setMetaInformation(QTextDocument::DocumentTitle, title);
             data = codec->fromUnicode(doc.toHtml(encoding.toAscii()));
 
-            KIO::storedPut(data, saveUrl, -1, true, false, true);
+            KIO::storedPut(data, saveUrl, -1, KIO::Overwrite);
         }
         else if ( type == Ascii ) {
             QTextCodec *codec = QTextCodec::codecForName(encoding.toAscii());
@@ -1065,7 +1064,7 @@ void KJotsMain::saveToFile(KJotsMain::ExportType type)
                 data += codec->fromUnicode(entry->generateText());
             }
 
-            KIO::storedPut(data, saveUrl, -1, true, false, true);
+            KIO::storedPut(data, saveUrl, -1, KIO::Overwrite);
         }
         else if ( type == Native ) {
             foreach ( KJotsEntry *entry, entries ) {
@@ -1113,7 +1112,7 @@ void KJotsMain::saveToFile(KJotsMain::ExportType type)
                 outStream.flush();
                 delete interimFile;
 
-                KIO::move(tempUrl, saveUrl, true);
+                KIO::move(tempUrl, saveUrl);
             }
         }
     }
@@ -1133,7 +1132,8 @@ void KJotsMain::importBook()
 
         if ( file.open() ) {
             KUrl bookUrl = KUrl::fromPath(file.fileName());
-            if ( KIO::NetAccess::file_copy(openUrl, bookUrl, 0644, true) ) {
+            KIO::Job* job = KIO::file_copy(openUrl, bookUrl, 0644);
+            if ( job->exec() ) {
                 KJotsBook* book = new KJotsBook();
                 bookshelf->addTopLevelItem(book);
                 book->openBook(file.fileName());
