@@ -195,7 +195,7 @@ KJotsBook::KJotsBook()
 {
     m_isBook = true;
     m_open = m_shouldBeOpened = m_dirty = false;
-    setIcon(0, KIconLoader::global()->loadIcon(QString("help-contents"),K3Icon::Small));
+    setIcon(0, KIconLoader::global()->loadIcon(QString("help-contents"),KIconLoader::Small));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled
         | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
 }
@@ -616,7 +616,7 @@ KJotsBook *KJotsBook::createNewBook ( void )
 KJotsPage::KJotsPage()
 {
     m_isBook = false;
-    setIcon(0, KIconLoader::global()->loadIcon(QString("edit"), K3Icon::Small));
+    setIcon(0, KIconLoader::global()->loadIcon(QString("edit"), KIconLoader::Small));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsDragEnabled
         | Qt::ItemIsEnabled);
     connect(&document, SIGNAL(modificationChanged(bool)), SLOT(documentModified(bool)));
