@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kmilo_kvaio.h 654754 2007-04-16 21:18:28Z mlaurent $
+   $Id: kmilo_kvaio.h 719088 2007-09-30 09:53:24Z mlaurent $
 
    * Portions of this code are
    * (C) 2001-2002 Stelian Pop <stelian@popies.net> and
@@ -36,7 +36,7 @@ class KMiloKVaio : public KMilo::Monitor {
 //	Q_OBJECT
 
 	public:
-		KMiloKVaio(QObject *parent, const QStringList&);
+		KMiloKVaio(QObject *parent, const QVariantList&);
 		virtual ~KMiloKVaio();
 
 		virtual bool init();
