@@ -463,7 +463,7 @@ void KWalletEditor::entrySelectionChanged(Q3ListViewItem *item) {
 	if (fi) {
 		_currentFolder = fi->name();
 		_ww->_entryTitle->setText(QString("<font size=\"+1\">%1</font>").arg(fi->text(0)));
-		_ww->_iconTitle->setPixmap(fi->getFolderIcon(K3Icon::Toolbar));
+		_ww->_iconTitle->setPixmap(fi->getFolderIcon(KIconLoader::Toolbar));
 	}
 }
 
