@@ -35,6 +35,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <KGlobal>
 #include <KIconLoader>
+#include <KConfigGroup>
 #include <KLocale>
 #include <K3StaticDeleter>
 #include <KWindowSystem>
@@ -572,9 +573,9 @@ Task::Task(WId win, QObject *parent, const char *name)
     // try to guess the icon from the classhint
     if (_pixmap.isNull()) {
         KIconLoader::global()->loadIcon(className().toLower(),
-                                        K3Icon::Small,
-                                        K3Icon::Small,
-                                        K3Icon::DefaultState,
+                                        KIconLoader::Small,
+                                        KIconLoader::Small,
+                                        KIconLoader::DefaultState,
                                         QStringList(),0, true);
     }
 
@@ -643,9 +644,9 @@ void Task::refreshIcon()
     // try to guess the icon from the classhint
     if (_pixmap.isNull()) {
         KIconLoader::global()->loadIcon(className().toLower(),
-                                        K3Icon::Small,
-                                        K3Icon::Small,
-                                        K3Icon::DefaultState,
+                                        KIconLoader::Small,
+                                        KIconLoader::Small,
+                                        KIconLoader::DefaultState,
                                         QStringList(),0, true);
     }
 
@@ -835,19 +836,19 @@ QPixmap Task::bestIcon(int size, bool &isStaticIcon)
     isStaticIcon = false;
 
     switch (size) {
-    case K3Icon::SizeSmall: {
+    case KIconLoader::SizeSmall: {
             pixmap = icon(16, 16, true);
 
             // Icon of last resort
             if (pixmap.isNull()) {
                 pixmap = KIconLoader::global()->loadIcon("go",
-                         K3Icon::NoGroup,
-                         K3Icon::SizeSmall);
+                         KIconLoader::NoGroup,
+                         KIconLoader::SizeSmall);
                 isStaticIcon = true;
             }
         }
         break;
-    case K3Icon::SizeMedium: {
+    case KIconLoader::SizeMedium: {
             //
             // Try 34x34 first for KDE 2.1 icons with shadows, if we don't
             // get one then try 32x32.
@@ -862,22 +863,22 @@ QPixmap Task::bestIcon(int size, bool &isStaticIcon)
             // Icon of last resort
             if (pixmap.isNull()) {
                 pixmap = KIconLoader::global()->loadIcon("go",
-                         K3Icon::NoGroup,
-                         K3Icon::SizeMedium);
+                         KIconLoader::NoGroup,
+                         KIconLoader::SizeMedium);
                 isStaticIcon = true;
             }
         }
         break;
-    case K3Icon::SizeLarge: {
+    case KIconLoader::SizeLarge: {
             // If there's a 48x48 icon in the hints then use it
             pixmap = icon(size, size, false);
 
             // If not, try to get one from the classname
             if (pixmap.isNull() || pixmap.width() != size || pixmap.height() != size) {
                 pixmap = KIconLoader::global()->loadIcon(className(),
-                         K3Icon::NoGroup,
+                         KIconLoader::NoGroup,
                          size,
-                         K3Icon::DefaultState,
+                         KIconLoader::DefaultState,
                          QStringList(),0L,
                          true);
                 isStaticIcon = true;
@@ -892,7 +893,7 @@ QPixmap Task::bestIcon(int size, bool &isStaticIcon)
             // Icon of last resort
             if (pixmap.isNull()) {
                 pixmap = KIconLoader::global()->loadIcon("go",
-                         K3Icon::NoGroup,
+                         KIconLoader::NoGroup,
                          size);
                 isStaticIcon = true;
             }
